[orca] Additional case for the regression test for bgo#590680 - OpenOffice.org toolbar items are not presen
- From: Joanmarie Diggs <joanied src gnome org>
- To: svn-commits-list gnome org
- Cc:
- Subject: [orca] Additional case for the regression test for bgo#590680 - OpenOffice.org toolbar items are not presen
- Date: Sat, 15 Aug 2009 03:02:08 +0000 (UTC)
commit 4a6f8e8800e8e8f5b058988439e4692bf20216fe
Author: Joanmarie Diggs <joanmarie diggs gmail com>
Date: Fri Aug 14 22:59:32 2009 -0400
Additional case for the regression test for bgo#590680 - OpenOffice.org toolbar items are not presented ideally (or at all).
test/keystrokes/oowriter/toolbar-buttons.py | 102 +++++++++++++++++++--------
1 files changed, 73 insertions(+), 29 deletions(-)
---
diff --git a/test/keystrokes/oowriter/toolbar-buttons.py b/test/keystrokes/oowriter/toolbar-buttons.py
index a3db520..de4b137 100644
--- a/test/keystrokes/oowriter/toolbar-buttons.py
+++ b/test/keystrokes/oowriter/toolbar-buttons.py
@@ -14,6 +14,12 @@ sequence.append(WaitForWindowActivate("Untitled[ ]*1 - " + utils.getOOoName("Wri
sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
######################################################################
+# Create a new document
+#
+sequence.append(KeyComboAction("<Control>n"))
+sequence.append(PauseAction(3000))
+
+######################################################################
# Press F6 until focus is on the Standard toolbar then Right arrow
# amongst the buttons. Also try to get a tooltip.
#
@@ -22,9 +28,9 @@ sequence.append(KeyComboAction("F6"))
sequence.append(WaitForFocus("File", acc_role=pyatspi.ROLE_MENU))
sequence.append(utils.AssertPresentationAction(
"F6 to menu bar",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane MenuBar'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane MenuBar'",
" VISIBLE: 'MenuBar', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane File Menu'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane File Menu'",
" VISIBLE: 'File Menu', cursor=1",
"SPEECH OUTPUT: 'menu bar'",
"SPEECH OUTPUT: 'File menu'"]))
@@ -35,9 +41,9 @@ sequence.append(WaitForFocus("New", acc_role=pyatspi.ROLE_PUSH_BUTTON))
sequence.append(utils.AssertPresentationAction(
"F6 to Standard toolbar",
["BUG? - We should not be saying 'off' for this button and the buttons that follow.",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Standard ToolBar'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Standard ToolBar'",
" VISIBLE: 'Standard ToolBar', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Standard ToolBar New Button'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Standard ToolBar New Button'",
" VISIBLE: 'New Button', cursor=1",
"SPEECH OUTPUT: 'Standard tool bar'",
"SPEECH OUTPUT: 'New off'"]))
@@ -54,7 +60,7 @@ sequence.append(KeyComboAction("Right"))
sequence.append(WaitForFocus("Open", acc_role=pyatspi.ROLE_PUSH_BUTTON))
sequence.append(utils.AssertPresentationAction(
"Right Arrow to Open button",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Standard ToolBar Open Button'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Standard ToolBar Open Button'",
" VISIBLE: 'Open Button', cursor=1",
"SPEECH OUTPUT: 'Open off'"]))
@@ -63,7 +69,7 @@ sequence.append(KeyComboAction("Right"))
sequence.append(WaitForFocus("Save", acc_role=pyatspi.ROLE_PUSH_BUTTON))
sequence.append(utils.AssertPresentationAction(
"Right Arrow to Save button",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Standard ToolBar Save Button'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Standard ToolBar Save Button'",
" VISIBLE: 'Save Button', cursor=1",
"SPEECH OUTPUT: 'Save off grayed'"]))
@@ -76,9 +82,9 @@ sequence.append(KeyComboAction("F6"))
sequence.append(WaitForFocus("Styles and Formatting", acc_role=pyatspi.ROLE_TOGGLE_BUTTON))
sequence.append(utils.AssertPresentationAction(
"F6 to Formatting Toolbar",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar'",
" VISIBLE: 'Formatting ToolBar', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar & y Styles and Formatting ToggleButton'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar & y Styles and Formatting ToggleButton'",
" VISIBLE: '& y Styles and Formatting Toggle', cursor=1",
"SPEECH OUTPUT: 'Formatting tool bar'",
"SPEECH OUTPUT: 'Styles and Formatting'"]))
@@ -88,7 +94,7 @@ sequence.append(KeyComboAction("Right"))
sequence.append(WaitForFocus("Apply Style", acc_role=pyatspi.ROLE_PANEL))
sequence.append(utils.AssertPresentationAction(
"Right to Apply Style",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel'",
" VISIBLE: 'Apply Style Panel', cursor=1",
"SPEECH OUTPUT: 'Apply Style panel'"]))
@@ -181,11 +187,11 @@ sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
"1. Down in Apply Style (Collapsed) - Take 2",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
" VISIBLE: 'Heading 1 $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
" VISIBLE: 'Heading 1 $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
" VISIBLE: 'Heading 1 $l', cursor=10",
"SPEECH OUTPUT: 'Heading 1'",
"SPEECH OUTPUT: 'selected'"]))
@@ -195,9 +201,9 @@ sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
"2. Down in Apply Style (Collapsed) - Take 2",
["BUG? - We shouldn't be saying 'selected' here once, let alone twice. And we're not speaking the newly selected item. This bug appears quite a bit in this test, but I'm only marking it once.",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 2 \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 2 \$l'",
" VISIBLE: 'Heading 2 $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 2 \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 2 \$l'",
" VISIBLE: 'Heading 2 $l', cursor=1",
"SPEECH OUTPUT: 'selected'",
"SPEECH OUTPUT: 'selected'"]))
@@ -215,9 +221,9 @@ sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
"1. Down in Apply Style (Expanded) - Take 2",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 3 \$l'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 3 \$l'",
" VISIBLE: 'Heading 3 $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 3 \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 3 \$l'",
" VISIBLE: 'Heading 3 $l', cursor=1",
"SPEECH OUTPUT: 'selected'",
"SPEECH OUTPUT: 'selected'"]))
@@ -226,9 +232,9 @@ sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
sequence.append(utils.AssertPresentationAction(
"2. Down in Apply Style (Expanded) - Take 2",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Text body \$l'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Text body \$l'",
" VISIBLE: 'Text body $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Text body \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Text body \$l'",
" VISIBLE: 'Text body $l', cursor=1",
"SPEECH OUTPUT: 'selected'",
"SPEECH OUTPUT: 'selected'"]))
@@ -240,9 +246,9 @@ sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
"1. Up in Apply Style (Expanded) - Take 2",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 3 \$l'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 3 \$l'",
" VISIBLE: 'Heading 3 $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 3 \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 3 \$l'",
" VISIBLE: 'Heading 3 $l', cursor=1",
"SPEECH OUTPUT: 'selected'",
"SPEECH OUTPUT: 'selected'"]))
@@ -251,9 +257,9 @@ sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
"2. Up in Apply Style (Expanded) - Take 2",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 2 \$l'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 2 \$l'",
" VISIBLE: 'Heading 2 $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 2 \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 2 \$l'",
" VISIBLE: 'Heading 2 $l', cursor=1",
"SPEECH OUTPUT: 'selected'",
"SPEECH OUTPUT: 'selected'"]))
@@ -262,9 +268,9 @@ sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
"3. Up in Apply Style (Expanded) - Take 2",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
" VISIBLE: 'Heading 1 $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Heading 1 \$l'",
" VISIBLE: 'Heading 1 $l', cursor=1",
"SPEECH OUTPUT: 'selected'",
"SPEECH OUTPUT: 'selected'"]))
@@ -273,20 +279,21 @@ sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Up"))
sequence.append(utils.AssertPresentationAction(
"4. Up in Apply Style (Expanded) - Take 2",
- ["BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Default \$l'",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Default \$l'",
" VISIBLE: 'Default $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Default \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Default \$l'",
" VISIBLE: 'Default $l', cursor=1",
- "BRAILLE LINE: 'soffice Application Untitled[ ]*1 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*1 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Default \$l'",
+ "BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Apply Style Panel Default \$l'",
" VISIBLE: 'Default $l', cursor=8",
"SPEECH OUTPUT: 'Default'",
"SPEECH OUTPUT: 'selected'"]))
######################################################################
# Press Escape to exit the list. Then Tab to the Bold toggle/push
# button.
#
-sequence.append(KeyComboAction("Escape"))
+sequence.append(KeyComboAction("<Alt>Up"))
+sequence.append(PauseAction(3000))
sequence.append(KeyComboAction("Tab"))
sequence.append(WaitForFocus("Font Name", acc_role=pyatspi.ROLE_PANEL))
@@ -294,8 +301,15 @@ sequence.append(WaitForFocus("Font Name", acc_role=pyatspi.ROLE_PANEL))
sequence.append(KeyComboAction("Tab"))
sequence.append(WaitForFocus("Font Size", acc_role=pyatspi.ROLE_PANEL))
+sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Tab"))
sequence.append(WaitForFocus("Bold", acc_role=pyatspi.ROLE_PUSH_BUTTON))
+sequence.append(PauseAction(1000))
+sequence.append(utils.AssertPresentationAction(
+ "Tab to Bold",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Bold Button'",
+ " VISIBLE: 'Bold Button', cursor=1",
+ "SPEECH OUTPUT: 'Bold off'"]))
######################################################################
# Press Return to toggle the state of the Bold toggle/push button.
@@ -306,8 +320,32 @@ sequence.append(utils.AssertPresentationAction(
"Return to toggle Bold on",
["BUG? - We're presenting nothing."]))
+######################################################################
+# Tab off of this item and then Shift+Tab back.
+#
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("Tab"))
+sequence.append(WaitForFocus("Italic", acc_role=pyatspi.ROLE_PUSH_BUTTON))
+sequence.append(PauseAction(1000))
+sequence.append(utils.AssertPresentationAction(
+ "Tab to Italic",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Italic Button'",
+ " VISIBLE: 'Italic Button', cursor=1",
+ "SPEECH OUTPUT: 'Italic off'"]))
+
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
+sequence.append(WaitForFocus("Bold", acc_role=pyatspi.ROLE_PUSH_BUTTON))
sequence.append(PauseAction(1000))
+sequence.append(utils.AssertPresentationAction(
+ "Shift Tab to Bold",
+ ["BRAILLE LINE: 'soffice Application Untitled[ ]*2 - " + utils.getOOoName("Writer") + " Frame Untitled[ ]*2 - " + utils.getOOoName("Writer") + " RootPane Formatting ToolBar Bold Button'",
+ " VISIBLE: 'Bold Button', cursor=1",
+ "SPEECH OUTPUT: 'Bold on'"]))
+######################################################################
+# Press Return to toggle the state of the Bold toggle/push button.
+#
sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Return"))
sequence.append(utils.AssertPresentationAction(
@@ -321,6 +359,12 @@ sequence.append(KeyComboAction("F6"))
sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_PARAGRAPH))
######################################################################
+# Close the new document
+#
+sequence.append(KeyComboAction("<Control>w"))
+sequence.append(PauseAction(3000))
+
+######################################################################
# Tab and Return to discard the current changes.
#
sequence.append(KeyComboAction("Tab"))
@@ -273,20 +279,21 @@ sequence.append(utils.StartRecordingAction())
"SPEECH OUTPUT: 'selected'"]))
######################################################################
-# Press Escape to exit the list. Then Tab to the Bold toggle/push
+# Press Alt Up to collapse the list. Then Tab to the Bold toggle/push
# button.
#
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]